[libpng14] Imported from libpng-1.4.15beta02.tar
diff --git a/CMakeLists.txt b/CMakeLists.txt
index 4da63fd..c3ff62f 100644
--- a/CMakeLists.txt
+++ b/CMakeLists.txt
@@ -255,7 +255,7 @@
 # SET UP LINKS
 if(PNG_SHARED)
   set_target_properties(${PNG_LIB_NAME} PROPERTIES
-#   VERSION 14.${PNGLIB_RELEASE}.1.4.15beta01
+#   VERSION 14.${PNGLIB_RELEASE}.1.4.15beta02
     VERSION 14.${PNGLIB_RELEASE}.0
     SOVERSION 14
     CLEAN_DIRECT_OUTPUT 1)
diff --git a/INSTALL b/INSTALL
index e968886..7d9b8bf 100644
--- a/INSTALL
+++ b/INSTALL
@@ -1,5 +1,5 @@
 
-Installing libpng version 1.4.15beta01 - January 27, 2015
+Installing libpng version 1.4.15beta02 - January 30, 2015
 
 On Unix/Linux and similar systems, you can simply type
 
@@ -46,7 +46,7 @@
 correspond to the version of zlib that's installed.
 
 You can rename the directories that you downloaded (they
-might be called "libpng-1.4.15beta01" or "libpng14" and "zlib-1.2.3"
+might be called "libpng-1.4.15beta02" or "libpng14" and "zlib-1.2.3"
 or "zlib123") so that you have directories called "zlib" and "libpng".
 
 Your directory structure should look like this:
diff --git a/LICENSE b/LICENSE
index 27a09f1..78dc826 100644
--- a/LICENSE
+++ b/LICENSE
@@ -10,7 +10,7 @@
 
 This code is released under the libpng license.
 
-libpng versions 1.2.6, August 15, 2004, through 1.4.15beta01, January 27, 2015, are
+libpng versions 1.2.6, August 15, 2004, through 1.4.15beta02, January 30, 2015, are
 Copyright (c) 2004, 2006-2014 Glenn Randers-Pehrson, and are
 distributed according to the same disclaimer and license as libpng-1.2.5
 with the following individual added to the list of Contributing Authors
@@ -108,4 +108,4 @@
 
 Glenn Randers-Pehrson
 glennrp at users.sourceforge.net
-January 27, 2015
+January 30, 2015
diff --git a/Makefile.am b/Makefile.am
index 51a8f76..9c13943 100644
--- a/Makefile.am
+++ b/Makefile.am
@@ -79,7 +79,7 @@
 	${srcdir}/contrib/pngsuite/* \
 	${srcdir}/contrib/visupng/* \
 	$(TESTS) \
-	example.c libpng-1.4.15beta01.txt
+	example.c libpng-1.4.15beta02.txt
 
 CLEANFILES= pngout.png libpng@PNGLIB_MAJOR@@PNGLIB_MINOR@.pc libpng@PNGLIB_MAJOR@@PNGLIB_MINOR@-config libpng.vers \
 libpng.sym
diff --git a/Makefile.in b/Makefile.in
index bbd2496..c969bc6 100644
--- a/Makefile.in
+++ b/Makefile.in
@@ -616,7 +616,7 @@
 	${srcdir}/contrib/pngsuite/* \
 	${srcdir}/contrib/visupng/* \
 	$(TESTS) \
-	example.c libpng-1.4.15beta01.txt
+	example.c libpng-1.4.15beta02.txt
 
 CLEANFILES = pngout.png libpng@PNGLIB_MAJOR@@PNGLIB_MINOR@.pc libpng@PNGLIB_MAJOR@@PNGLIB_MINOR@-config libpng.vers \
 libpng.sym
diff --git a/README b/README
index c5eefd1..3e45f75 100644
--- a/README
+++ b/README
@@ -1,4 +1,4 @@
-README for libpng version 1.4.15beta01 - January 27, 2015 (shared library 14.0)
+README for libpng version 1.4.15beta02 - January 30, 2015 (shared library 14.0)
 See the note about version numbers near the top of png.h
 
 See INSTALL for instructions on how to install libpng.
@@ -187,9 +187,9 @@
        makefile.std     =>  Generic UNIX makefile (cc, creates static
                             libpng.a)
        makefile.elf     =>  Linux/ELF makefile symbol versioning,
-                            (gcc, creates libpng14.so.14.1.4.15beta01)
+                            (gcc, creates libpng14.so.14.1.4.15beta02)
        makefile.linux   =>  Linux/ELF makefile
-                            (gcc, creates libpng14.so.14.1.4.15beta01)
+                            (gcc, creates libpng14.so.14.1.4.15beta02)
        makefile.gcc     =>  Generic makefile (gcc, creates static libpng.a)
        makefile.knr     =>  Archaic UNIX Makefile that converts files with
                             ansi2knr (Requires ansi2knr.c from
@@ -211,12 +211,12 @@
        makefile.openbsd =>  OpenBSD makefile
        makefile.sgi     =>  Silicon Graphics IRIX (cc, creates static lib)
        makefile.sggcc   =>  Silicon Graphics
-                            (gcc, creates libpng14.so.14.1.4.15beta01)
+                            (gcc, creates libpng14.so.14.1.4.15beta02)
        makefile.sunos   =>  Sun makefile
        makefile.solaris =>  Solaris 2.X makefile
-                            (gcc, creates libpng14.so.14.1.4.15beta01)
+                            (gcc, creates libpng14.so.14.1.4.15beta02)
        makefile.so9     =>  Solaris 9 makefile
-                            (gcc, creates libpng14.so.14.1.4.15beta01)
+                            (gcc, creates libpng14.so.14.1.4.15beta02)
        makefile.32sunu  =>  Sun Ultra 32-bit makefile
        makefile.64sunu  =>  Sun Ultra 64-bit makefile
        makefile.sco     =>  For SCO OSr5  ELF and Unixware 7 with Native cc
diff --git a/configure b/configure
index 7d08ecd..d257803 100755
--- a/configure
+++ b/configure
@@ -1,6 +1,6 @@
 #! /bin/sh
 # Guess values for system-dependent variables and create Makefiles.
-# Generated by GNU Autoconf 2.69 for libpng 1.4.15beta01.
+# Generated by GNU Autoconf 2.69 for libpng 1.4.15beta02.
 #
 # Report bugs to <png-mng-implement@lists.sourceforge.net>.
 #
@@ -590,8 +590,8 @@
 # Identity of this package.
 PACKAGE_NAME='libpng'
 PACKAGE_TARNAME='libpng'
-PACKAGE_VERSION='1.4.15beta01'
-PACKAGE_STRING='libpng 1.4.15beta01'
+PACKAGE_VERSION='1.4.15beta02'
+PACKAGE_STRING='libpng 1.4.15beta02'
 PACKAGE_BUGREPORT='png-mng-implement@lists.sourceforge.net'
 PACKAGE_URL=''
 
@@ -1330,7 +1330,7 @@
   # Omit some internal or obsolete options to make the list less imposing.
   # This message is too long to be a string in the A/UX 3.1 sh.
   cat <<_ACEOF
-\`configure' configures libpng 1.4.15beta01 to adapt to many kinds of systems.
+\`configure' configures libpng 1.4.15beta02 to adapt to many kinds of systems.
 
 Usage: $0 [OPTION]... [VAR=VALUE]...
 
@@ -1400,7 +1400,7 @@
 
 if test -n "$ac_init_help"; then
   case $ac_init_help in
-     short | recursive ) echo "Configuration of libpng 1.4.15beta01:";;
+     short | recursive ) echo "Configuration of libpng 1.4.15beta02:";;
    esac
   cat <<\_ACEOF
 
@@ -1512,7 +1512,7 @@
 test -n "$ac_init_help" && exit $ac_status
 if $ac_init_version; then
   cat <<\_ACEOF
-libpng configure 1.4.15beta01
+libpng configure 1.4.15beta02
 generated by GNU Autoconf 2.69
 
 Copyright (C) 2012 Free Software Foundation, Inc.
@@ -1935,7 +1935,7 @@
 This file contains any messages produced by compilers while
 running configure, to aid debugging if configure makes a mistake.
 
-It was created by libpng $as_me 1.4.15beta01, which was
+It was created by libpng $as_me 1.4.15beta02, which was
 generated by GNU Autoconf 2.69.  Invocation command line was
 
   $ $0 $@
@@ -2798,7 +2798,7 @@
 
 # Define the identity of the package.
  PACKAGE='libpng'
- VERSION='1.4.15beta01'
+ VERSION='1.4.15beta02'
 
 
 cat >>confdefs.h <<_ACEOF
@@ -2914,7 +2914,7 @@
 
 
 
-PNGLIB_VERSION=1.4.15beta01
+PNGLIB_VERSION=1.4.15beta02
 PNGLIB_MAJOR=1
 PNGLIB_MINOR=4
 PNGLIB_RELEASE=15
@@ -13119,7 +13119,7 @@
 # report actual input values of CONFIG_FILES etc. instead of their
 # values after options handling.
 ac_log="
-This file was extended by libpng $as_me 1.4.15beta01, which was
+This file was extended by libpng $as_me 1.4.15beta02, which was
 generated by GNU Autoconf 2.69.  Invocation command line was
 
   CONFIG_FILES    = $CONFIG_FILES
@@ -13185,7 +13185,7 @@
 cat >>$CONFIG_STATUS <<_ACEOF || ac_write_fail=1
 ac_cs_config="`$as_echo "$ac_configure_args" | sed 's/^ //; s/[\\""\`\$]/\\\\&/g'`"
 ac_cs_version="\\
-libpng config.status 1.4.15beta01
+libpng config.status 1.4.15beta02
 configured by $0, generated by GNU Autoconf 2.69,
   with options \\"\$ac_cs_config\\"
 
diff --git a/configure.ac b/configure.ac
index bfb3073..dec904e 100644
--- a/configure.ac
+++ b/configure.ac
@@ -16,14 +16,14 @@
 dnl stamps are correct
 AC_PREREQ(2.59)
 
-AC_INIT([libpng], [1.4.15beta01], [png-mng-implement@lists.sourceforge.net])
+AC_INIT([libpng], [1.4.15beta02], [png-mng-implement@lists.sourceforge.net])
 AM_INIT_AUTOMAKE
 dnl stop configure from automagically running automake
 AM_MAINTAINER_MODE
 
 dnl Version number stuff here:
 
-PNGLIB_VERSION=1.4.15beta01
+PNGLIB_VERSION=1.4.15beta02
 PNGLIB_MAJOR=1
 PNGLIB_MINOR=4
 PNGLIB_RELEASE=15
diff --git a/libpng-1.4.15beta01.txt b/libpng-1.4.15beta02.txt
similarity index 99%
rename from libpng-1.4.15beta01.txt
rename to libpng-1.4.15beta02.txt
index b3e7c64..b244587 100644
--- a/libpng-1.4.15beta01.txt
+++ b/libpng-1.4.15beta02.txt
@@ -1,6 +1,6 @@
 libpng.txt - A description on how to use and modify libpng
 
- libpng version 1.4.15beta01 - January 27, 2015
+ libpng version 1.4.15beta02 - January 30, 2015
  Updated and distributed by Glenn Randers-Pehrson
  <glennrp at users.sourceforge.net>
  Copyright (c) 1998-2014 Glenn Randers-Pehrson
@@ -11,7 +11,7 @@
 
  Based on:
 
- libpng versions 0.97, January 1998, through 1.4.15beta01 - January 27, 2015
+ libpng versions 0.97, January 1998, through 1.4.15beta02 - January 30, 2015
  Updated and distributed by Glenn Randers-Pehrson
  Copyright (c) 1998-2014 Glenn Randers-Pehrson
 
@@ -906,7 +906,7 @@
 As of libpng version 1.2.9, png_set_expand_gray_1_2_4_to_8() was
 added.  It expands the sample depth without changing tRNS to alpha.
 
-As of libpng version 1.4.15beta01, not all possible expansions are supported.
+As of libpng version 1.4.15beta02, not all possible expansions are supported.
 
 In the following table, the 01 means grayscale with depth<8, 31 means
 indexed with depth<8, other numerals represent the color type, "T" means
@@ -3316,13 +3316,13 @@
 
 XIII. Y2K Compliance in libpng
 
-January 27, 2015
+January 30, 2015
 
 Since the PNG Development group is an ad-hoc body, we can't make
 an official declaration.
 
 This is your unofficial assurance that libpng from version 0.71 and
-upward through 1.4.15beta01 are Y2K compliant.  It is my belief that earlier
+upward through 1.4.15beta02 are Y2K compliant.  It is my belief that earlier
 versions were also Y2K compliant.
 
 Libpng only has three year fields.  One is a 2-byte unsigned integer that
diff --git a/libpng.3 b/libpng.3
index b74c884..fc79bc3 100644
--- a/libpng.3
+++ b/libpng.3
@@ -1,6 +1,6 @@
-.TH LIBPNG 3 "January 27, 2015"
+.TH LIBPNG 3 "January 30, 2015"
 .SH NAME
-libpng \- Portable Network Graphics (PNG) Reference Library 1.4.15beta01
+libpng \- Portable Network Graphics (PNG) Reference Library 1.4.15beta02
 .SH SYNOPSIS
 \fB
 #include <png.h>\fP
@@ -442,7 +442,7 @@
 .SH LIBPNG.TXT
 libpng.txt - A description on how to use and modify libpng
 
- libpng version 1.4.15beta01 - January 27, 2015
+ libpng version 1.4.15beta02 - January 30, 2015
  Updated and distributed by Glenn Randers-Pehrson
  <glennrp at users.sourceforge.net>
  Copyright (c) 1998-2014 Glenn Randers-Pehrson
@@ -453,7 +453,7 @@
 
  Based on:
 
- libpng versions 0.97, January 1998, through 1.4.15beta01 - January 27, 2015
+ libpng versions 0.97, January 1998, through 1.4.15beta02 - January 30, 2015
  Updated and distributed by Glenn Randers-Pehrson
  Copyright (c) 1998-2014 Glenn Randers-Pehrson
 
@@ -1348,7 +1348,7 @@
 As of libpng version 1.2.9, png_set_expand_gray_1_2_4_to_8() was
 added.  It expands the sample depth without changing tRNS to alpha.
 
-As of libpng version 1.4.15beta01, not all possible expansions are supported.
+As of libpng version 1.4.15beta02, not all possible expansions are supported.
 
 In the following table, the 01 means grayscale with depth<8, 31 means
 indexed with depth<8, other numerals represent the color type, "T" means
@@ -3758,13 +3758,13 @@
 
 .SH XIII. Y2K Compliance in libpng
 
-January 27, 2015
+January 30, 2015
 
 Since the PNG Development group is an ad-hoc body, we can't make
 an official declaration.
 
 This is your unofficial assurance that libpng from version 0.71 and
-upward through 1.4.15beta01 are Y2K compliant.  It is my belief that earlier
+upward through 1.4.15beta02 are Y2K compliant.  It is my belief that earlier
 versions were also Y2K compliant.
 
 Libpng only has three year fields.  One is a 2-byte unsigned integer that
@@ -3979,7 +3979,7 @@
  1.4.14beta01        14    10414  14.so.14.14[.0]
  1.4.14rc01-02       14    10414  14.so.14.14[.0]
  1.4.14              14    10414  14.so.14.14[.0]
- 1.4.15beta01        14    10415  14.so.14.15[.0]
+ 1.4.15beta01-02     14    10415  14.so.14.15[.0]
 
 Henceforth the source version will match the shared-library minor
 and patch numbers; the shared-library major version number will be
@@ -4035,7 +4035,7 @@
 
 Thanks to Frank J. T. Wojcik for helping with the documentation.
 
-Libpng version 1.4.15beta01 - January 27, 2015:
+Libpng version 1.4.15beta02 - January 30, 2015:
 Initially created in 1995 by Guy Eric Schalnat, then of Group 42, Inc.
 Currently maintained by Glenn Randers-Pehrson (glennrp at users.sourceforge.net).
 
@@ -4058,7 +4058,7 @@
 
 This code is released under the libpng license.
 
-libpng versions 1.2.6, August 15, 2004, through 1.4.15beta01, January 27, 2015, are
+libpng versions 1.2.6, August 15, 2004, through 1.4.15beta02, January 30, 2015, are
 Copyright (c) 2004,2006-2007 Glenn Randers-Pehrson, and are
 distributed according to the same disclaimer and license as libpng-1.2.5
 with the following individual added to the list of Contributing Authors
@@ -4157,7 +4157,7 @@
 
 Glenn Randers-Pehrson
 glennrp at users.sourceforge.net
-January 27, 2015
+January 30, 2015
 
 .\" end of man page
 
diff --git a/libpngpf.3 b/libpngpf.3
index ce3b9d5..6dd7270 100644
--- a/libpngpf.3
+++ b/libpngpf.3
@@ -1,6 +1,6 @@
-.TH LIBPNGPF 3 "January 27, 2015"
+.TH LIBPNGPF 3 "January 30, 2015"
 .SH NAME
-libpng \- Portable Network Graphics (PNG) Reference Library 1.4.15beta01
+libpng \- Portable Network Graphics (PNG) Reference Library 1.4.15beta02
 (private functions)
 .SH SYNOPSIS
 \fB#include <png.h>
diff --git a/png.5 b/png.5
index ac58344..444c0a8 100644
--- a/png.5
+++ b/png.5
@@ -1,4 +1,4 @@
-.TH PNG 5 "January 27, 2015"
+.TH PNG 5 "January 30, 2015"
 .SH NAME
 png \- Portable Network Graphics (PNG) format
 .SH DESCRIPTION
diff --git a/pngconf.h b/pngconf.h
index cf63bd1..d2780ae 100644
--- a/pngconf.h
+++ b/pngconf.h
@@ -1,7 +1,7 @@
 
 /* pngconf.h - machine configurable file for libpng
  *
- * libpng version %VER% - %DATE%
+ * libpng version 1.4.15beta02 - January 30, 2015
  * For conditions of distribution and use, see copyright notice in png.h
  * Copyright (c) 1998-2011 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -59,7 +59,7 @@
  *        distinguish your DLL from those of the official release. These
  *        correspond to the trailing letters that come after the version
  *        number and must match your private DLL name>
- *  e.g. // private DLL "libpng%NN%gx.dll"
+ *  e.g. // private DLL "libpng14gx.dll"
  *       #define PNG_USER_DLLFNAME_POSTFIX "gx"
  *
  * The following macros are also at your disposal if you want to complete the
@@ -352,8 +352,7 @@
 #endif
 
 /* Enough people need this for various reasons to include it here */
-%12-%#if !defined(MACOS) && !defined(RISCOS) && !defined(_WIN32_WCE)
-%14+%#if !defined(MACOS) && !defined(RISCOS)
+#if !defined(MACOS) && !defined(RISCOS)
 #  include <sys/types.h>
 #endif
 
@@ -500,46 +499,12 @@
  * 1.4.0)
  */
 
-%12-%/* The following support, added after version 1.0.0, can be turned off
-%12-% * here en masse by defining PNG_LEGACY_SUPPORTED in case you need binary
-%12-% * compatibility with old applications that require the length of
-%12-% * png_struct and png_info to remain unchanged.
-%12-% */
-%12-%
-%12-%#ifdef PNG_LEGACY_SUPPORTED
-%12-%#  define PNG_NO_FREE_ME
-%12-%#  define PNG_NO_READ_UNKNOWN_CHUNKS
-%12-%#  define PNG_NO_WRITE_UNKNOWN_CHUNKS
-%12-%#  define PNG_NO_HANDLE_AS_UNKNOWN
-%12-%#  define PNG_NO_READ_USER_CHUNKS
-%12-%#  define PNG_NO_READ_iCCP
-%12-%#  define PNG_NO_WRITE_iCCP
-%12-%#  define PNG_NO_READ_iTXt
-%12-%#  define PNG_NO_WRITE_iTXt
-%12-%#  define PNG_NO_READ_sCAL
-%12-%#  define PNG_NO_WRITE_sCAL
-%12-%#  define PNG_NO_READ_sPLT
-%12-%#  define PNG_NO_WRITE_sPLT
-%12-%#  define PNG_NO_INFO_IMAGE
-%12-%#  define PNG_NO_READ_RGB_TO_GRAY
-%12-%#  define PNG_NO_READ_USER_TRANSFORM
-%12-%#  define PNG_NO_WRITE_USER_TRANSFORM
-%12-%#  define PNG_NO_USER_MEM
-%12-%#  define PNG_NO_READ_EMPTY_PLTE
-%12-%#  define PNG_NO_MNG_FEATURES
-%12-%#  define PNG_NO_FIXED_POINT_SUPPORTED
-%12-%#endif
-%12-%
 /* Ignore attempt to turn off both floating and fixed point support */
 #if !defined(PNG_FLOATING_POINT_SUPPORTED) || \
     !defined(PNG_NO_FIXED_POINT_SUPPORTED)
 #  define PNG_FIXED_POINT_SUPPORTED
 #endif
 
-%12-%#ifndef PNG_NO_FREE_ME
-%12-%#  define PNG_FREE_ME_SUPPORTED
-%12-%#endif
-%12-%
 #ifdef PNG_READ_SUPPORTED
 
 /* PNG_READ_TRANSFORMS_NOT_SUPPORTED is deprecated. */
@@ -707,10 +672,7 @@
 
 #endif /* PNG_WRITE_SUPPORTED */
 
-%14+%#define PNG_NO_ERROR_NUMBERS
-%12-%#ifndef PNG_NO_ERROR_NUMBERS
-%12-%#  define PNG_ERROR_NUMBERS_SUPPORTED
-%12-%#endif
+#define PNG_NO_ERROR_NUMBERS
 
 #if defined(PNG_READ_USER_TRANSFORM_SUPPORTED) || \
     defined(PNG_WRITE_USER_TRANSFORM_SUPPORTED)
@@ -792,23 +754,23 @@
 #  define PNG_USER_CHUNK_MALLOC_MAX 0
 #endif
 
-%14+%/* Added at libpng-1.4.0 */
-%14+%#if !defined(PNG_NO_IO_STATE) && !defined(PNG_IO_STATE_SUPPORTED)
-%14+%#  define PNG_IO_STATE_SUPPORTED
-%14+%#endif
-%14+%
-%14+%#ifndef PNG_LITERAL_SHARP
-%14+%#  define PNG_LITERAL_SHARP 0x23
-%14+%#endif
-%14+%#ifndef PNG_LITERAL_LEFT_SQUARE_BRACKET
-%14+%#  define PNG_LITERAL_LEFT_SQUARE_BRACKET 0x5b
-%14+%#endif
-%14+%#ifndef PNG_LITERAL_RIGHT_SQUARE_BRACKET
-%14+%#  define PNG_LITERAL_RIGHT_SQUARE_BRACKET 0x5d
-%14+%#endif
-%14+%#ifndef PNG_STRING_NEWLINE
-%14+%#define PNG_STRING_NEWLINE "\n"
-%14+%#endif
+/* Added at libpng-1.4.0 */
+#if !defined(PNG_NO_IO_STATE) && !defined(PNG_IO_STATE_SUPPORTED)
+#  define PNG_IO_STATE_SUPPORTED
+#endif
+
+#ifndef PNG_LITERAL_SHARP
+#  define PNG_LITERAL_SHARP 0x23
+#endif
+#ifndef PNG_LITERAL_LEFT_SQUARE_BRACKET
+#  define PNG_LITERAL_LEFT_SQUARE_BRACKET 0x5b
+#endif
+#ifndef PNG_LITERAL_RIGHT_SQUARE_BRACKET
+#  define PNG_LITERAL_RIGHT_SQUARE_BRACKET 0x5d
+#endif
+#ifndef PNG_STRING_NEWLINE
+#define PNG_STRING_NEWLINE "\n"
+#endif
 
 /* These are currently experimental features, define them if you want */
 
@@ -829,9 +791,9 @@
 #endif
 */
 
-%14+%#if !defined(PNG_NO_USE_READ_MACROS) && !defined(PNG_USE_READ_MACROS)
-%14+%#  define PNG_USE_READ_MACROS
-%14+%#endif
+#if !defined(PNG_NO_USE_READ_MACROS) && !defined(PNG_USE_READ_MACROS)
+#  define PNG_USE_READ_MACROS
+#endif
 
 /* Buggy compilers (e.g., gcc 2.7.2.2) need PNG_NO_POINTER_INDEXING */
 
@@ -840,13 +802,6 @@
 #  define PNG_POINTER_INDEXING_SUPPORTED
 #endif
 
-%12-%/* These functions are turned off by default, as they will be phased
-%12-% * out.
-%12-% */
-%12-%/*
-%12-%#define  PNG_USELESS_TESTS_SUPPORTED
-%12-%#define  PNG_CORRECT_PALETTE_SUPPORTED
-%12-%*/
 
 /* Any chunks you are not interested in, you can undef here.  The
  * ones that allocate memory may be expecially important (hIST,
@@ -1184,8 +1139,7 @@
 #define png_sizeof(x) (sizeof (x))
 
 /* The following is needed for medium model support.  It cannot be in the
-%12-% * PNG_INTERNAL section.  Needs modification for other compilers besides
-%14+% * pngpriv.h header.  Needs modification for other compilers besides
+ * pngpriv.h header.  Needs modification for other compilers besides
  * MSC.  Model independent support declares all arrays and pointers to be
  * large using the far keyword.  The zlib version used must also support
  * model independent data.  As of version zlib 1.0.4, the necessary changes
@@ -1260,11 +1214,7 @@
 typedef png_fixed_point FAR * png_fixed_point_p;
 
 #ifndef PNG_NO_STDIO
-%12-%#  ifdef _WIN32_WCE
-%12-%typedef HANDLE                png_FILE_p;
-%12-%#  else
 typedef FILE                * png_FILE_p;
-%12-%#  endif
 #endif
 
 #ifdef PNG_FLOATING_POINT_SUPPORTED
@@ -1420,8 +1370,7 @@
  * Added at libpng-1.2.41.
  */
 
-%12-%#ifdef PNG_PEDANTIC_WARNINGS
-%14+%#ifndef PNG_NO_PEDANTIC_WARNINGS
+#ifndef PNG_NO_PEDANTIC_WARNINGS
 #  ifndef PNG_PEDANTIC_WARNINGS_SUPPORTED
 #    define PNG_PEDANTIC_WARNINGS_SUPPORTED
 #  endif
diff --git a/pngpriv.h b/pngpriv.h
index 3ac6b15..ed908ec 100644
--- a/pngpriv.h
+++ b/pngpriv.h
@@ -1,7 +1,7 @@
 
 /* pngpriv.h - private declarations for use inside libpng
  *
- * libpng version %VER% - %DATE%
+ * libpng version 1.4.15beta02 - January 30, 2015
  * For conditions of distribution and use, see copyright notice in png.h
  * Copyright (c) 1998-2014 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -163,12 +163,9 @@
 #define PNG_FLAG_CRC_ANCILLARY_NOWARN     0x0200
 #define PNG_FLAG_CRC_CRITICAL_USE         0x0400
 #define PNG_FLAG_CRC_CRITICAL_IGNORE      0x0800
-%14+%                                /*        0x1000  unused */
-%14+%                                /*        0x2000  unused */
-%14+%                                /*        0x4000  unused */
-%12-%#define PNG_FLAG_FREE_PLTE                0x1000
-%12-%#define PNG_FLAG_FREE_TRNS                0x2000
-%12-%#define PNG_FLAG_FREE_HIST                0x4000
+                                /*        0x1000  unused */
+                                /*        0x2000  unused */
+                                /*        0x4000  unused */
 #define PNG_FLAG_KEEP_UNKNOWN_CHUNKS      0x8000L
 #define PNG_FLAG_KEEP_UNSAFE_CHUNKS       0x10000L
 #define PNG_FLAG_LIBRARY_MISMATCH         0x20000L
@@ -628,14 +625,14 @@
 #ifdef PNG_READ_BACKGROUND_SUPPORTED
 #ifdef PNG_READ_GAMMA_SUPPORTED
 PNG_EXTERN void png_do_background PNGARG((png_row_infop row_info, png_bytep row,
-   png_color_16p %TV%, png_color_16p background,
+   png_color_16p trans_color, png_color_16p background,
    png_color_16p background_1,
    png_bytep gamma_table, png_bytep gamma_from_1, png_bytep gamma_to_1,
    png_uint_16pp gamma_16, png_uint_16pp gamma_16_from_1,
    png_uint_16pp gamma_16_to_1, int gamma_shift));
 #else
 PNG_EXTERN void png_do_background PNGARG((png_row_infop row_info, png_bytep row,
-   png_color_16p %TV%, png_color_16p background));
+   png_color_16p trans_color, png_color_16p background));
 #endif
 #endif
 
@@ -828,8 +825,7 @@
 
 #ifdef PNG_cHRM_SUPPORTED
 #ifdef PNG_CHECK_cHRM_SUPPORTED
-%12-%/* Added at libpng version 1.2.34 */
-%14+%/* Added at libpng version 1.2.34 and 1.4.0 */
+/* Added at libpng version 1.2.34 and 1.4.0 */
 PNG_EXTERN void png_64bit_product PNGARG((long v1, long v2,
    unsigned long *hi_product, unsigned long *lo_product));
 #endif
diff --git a/pngtest.c b/pngtest.c
index 0b2abd3..c0bced6 100644
--- a/pngtest.c
+++ b/pngtest.c
@@ -1702,4 +1702,4 @@
 }
 
 /* Generate a compiler error if there is an old png.h in the search path. */
-typedef version_1_4_15beta01 your_png_h_is_not_version_1_4_15beta01;
+typedef version_1_4_15beta02 your_png_h_is_not_version_1_4_15beta02;
diff --git a/projects/vstudio/readme.txt b/projects/vstudio/readme.txt
index 54e61bd..aaf0bb1 100644
--- a/projects/vstudio/readme.txt
+++ b/projects/vstudio/readme.txt
@@ -1,7 +1,7 @@
 
 VisualStudio instructions
 
-libpng version 1.4.15beta01 - January 27, 2015
+libpng version 1.4.15beta02 - January 30, 2015
 
 Copyright (c) 1998-2010 Glenn Randers-Pehrson
 
diff --git a/projects/vstudio/zlib.props b/projects/vstudio/zlib.props
index f39d1d1..304c5e6 100644
--- a/projects/vstudio/zlib.props
+++ b/projects/vstudio/zlib.props
@@ -2,7 +2,7 @@
 <!--
  * zlib.props - location of zlib source and build
  *
- * libpng version 1.4.15beta01 - January 27, 2015
+ * libpng version 1.4.15beta02 - January 30, 2015
  *
  * Copyright (c) 1998-2011 Glenn Randers-Pehrson
  *
diff --git a/scripts/README.txt b/scripts/README.txt
index c7f92d9..7015cef 100644
--- a/scripts/README.txt
+++ b/scripts/README.txt
@@ -1,8 +1,8 @@
 
-Makefiles for  libpng version 1.4.15beta01 - January 27, 2015
+Makefiles for  libpng version 1.4.15beta02 - January 30, 2015
 
  makefile.linux    =>  Linux/ELF makefile
-                       (gcc, creates libpng14.so.14.1.4.15beta01)
+                       (gcc, creates libpng14.so.14.1.4.15beta02)
  makefile.gcc      =>  Generic makefile (gcc, creates static libpng.a)
  makefile.knr      =>  Archaic UNIX Makefile that converts files with
                        ansi2knr (Requires ansi2knr.c from
@@ -20,7 +20,7 @@
  makefile.dec      =>  DEC Alpha UNIX makefile
  makefile.dj2      =>  DJGPP 2 makefile
  makefile.elf      =>  Linux/ELF makefile symbol versioning,
-                       (gcc, creates libpng14.so.14.1.4.15beta01)
+                       (gcc, creates libpng14.so.14.1.4.15beta02)
  makefile.freebsd  =>  FreeBSD makefile
  makefile.gcc      =>  Generic gcc makefile
  makefile.hpgcc    =>  HPUX makefile using gcc
@@ -36,12 +36,12 @@
  makefile.os2      =>  OS/2 Makefile (gcc and emx, requires pngos2.def)
  makefile.sco      =>  For SCO OSr5  ELF and Unixware 7 with Native cc
  makefile.sggcc    =>  Silicon Graphics (gcc,
-                       creates libpng14.so.14.1.4.15beta01)
+                       creates libpng14.so.14.1.4.15beta02)
  makefile.sgi      =>  Silicon Graphics IRIX makefile (cc, creates static lib)
  makefile.solaris  =>  Solaris 2.X makefile (gcc,
-                       creates libpng14.so.14.1.4.15beta01)
+                       creates libpng14.so.14.1.4.15beta02)
  makefile.so9      =>  Solaris 9 makefile (gcc,
-                       creates libpng14.so.14.1.4.15beta01)
+                       creates libpng14.so.14.1.4.15beta02)
  makefile.std      =>  Generic UNIX makefile (cc, creates static libpng.a)
  makefile.sunos    =>  Sun makefile
  makefile.32sunu   =>  Sun Ultra 32-bit makefile
diff --git a/scripts/libpng-config-head.in b/scripts/libpng-config-head.in
index 7306329..453562f 100755
--- a/scripts/libpng-config-head.in
+++ b/scripts/libpng-config-head.in
@@ -11,7 +11,7 @@
 
 # Modeled after libxml-config.
 
-version=1.4.15beta01
+version=1.4.15beta02
 prefix=""
 libdir=""
 libs=""
diff --git a/scripts/libpng.pc.in b/scripts/libpng.pc.in
index 024902c..c15258f 100644
--- a/scripts/libpng.pc.in
+++ b/scripts/libpng.pc.in
@@ -5,6 +5,6 @@
 
 Name: libpng
 Description: Loads and saves PNG files
-Version: 1.4.15beta01
+Version: 1.4.15beta02
 Libs: -L${libdir} -lpng14
 Cflags: -I${includedir}
diff --git a/scripts/makefile.ne12bsd b/scripts/makefile.ne12bsd
index f3b77d5..04d98dc 100644
--- a/scripts/makefile.ne12bsd
+++ b/scripts/makefile.ne12bsd
@@ -17,7 +17,7 @@
 
 LIB=	png14
 SHLIB_MAJOR=	0
-SHLIB_MINOR=	1.4.15beta01
+SHLIB_MINOR=	1.4.15beta02
 SRCS=	png.c pngset.c pngget.c pngrutil.c pngtrans.c pngwutil.c \
 	pngread.c pngrio.c pngwio.c pngwrite.c pngrtran.c \
 	pngwtran.c pngmem.c pngerror.c pngpread.c
diff --git a/scripts/makefile.netbsd b/scripts/makefile.netbsd
index e9d4041..3502b36 100644
--- a/scripts/makefile.netbsd
+++ b/scripts/makefile.netbsd
@@ -17,7 +17,7 @@
 
 LIB=	png
 SHLIB_MAJOR=	3
-SHLIB_MINOR=	1.4.15beta01
+SHLIB_MINOR=	1.4.15beta02
 SRCS=	png.c pngset.c pngget.c pngrutil.c pngtrans.c pngwutil.c \
 	pngread.c pngrio.c pngwio.c pngwrite.c pngrtran.c \
 	pngwtran.c pngmem.c pngerror.c pngpread.c
diff --git a/scripts/makefile.openbsd b/scripts/makefile.openbsd
index 473bcd1..4e3d967 100644
--- a/scripts/makefile.openbsd
+++ b/scripts/makefile.openbsd
@@ -11,7 +11,7 @@
 MANDIR= ${PREFIX}/man/cat
 
 SHLIB_MAJOR=	0
-SHLIB_MINOR=	1.4.15beta01
+SHLIB_MINOR=	1.4.15beta02
 
 LIB=	png
 SRCS=	png.c pngerror.c pngget.c pngmem.c pngpread.c \
diff --git a/scripts/png32ce.def b/scripts/png32ce.def
index 4322a4f..30d6a16 100644
--- a/scripts/png32ce.def
+++ b/scripts/png32ce.def
@@ -15,7 +15,7 @@
  png_get_int_32
 
 EXPORTS
-;Version 1.4.15beta01
+;Version 1.4.15beta02
   png_build_grayscale_palette  @1
 ;  png_check_sig        @2
   png_chunk_error      @3
diff --git a/scripts/pngos2.def b/scripts/pngos2.def
index ab033f4..49d1ebf 100644
--- a/scripts/pngos2.def
+++ b/scripts/pngos2.def
@@ -2,7 +2,7 @@
 ; PNG.LIB module definition file for OS/2
 ;----------------------------------------
 
-; Version 1.4.15beta01
+; Version 1.4.15beta02
 
 LIBRARY		PNG
 DESCRIPTION	"PNG image compression library for OS/2"
diff --git a/scripts/pngwin.def b/scripts/pngwin.def
index b63e1b4..58d199d 100644
--- a/scripts/pngwin.def
+++ b/scripts/pngwin.def
@@ -5,7 +5,7 @@
 LIBRARY
 
 EXPORTS
-;Version 1.4.15beta01
+;Version 1.4.15beta02
   png_build_grayscale_palette
   png_chunk_error
   png_chunk_warning
diff --git a/png.h b/png.h
index 0b7b289..6afd49f 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
 
 /* png.h - header file for PNG reference library
  *
- * libpng version %VER% - %DATE%
+ * libpng version 1.4.15beta02 - January 30, 2015
  * Copyright (c) 1998-2011 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
  * (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -11,7 +11,7 @@
  * Authors and maintainers:
  *  libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
  *  libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
  *  libpng versions 0.97, January 1998, through %VER% - %DATE%: Glenn
  *  See also "Contributing Authors", below.
  *
  * Note about libpng version numbers:
@@ -208,7 +208,7 @@
  *
  * This code is released under the libpng license.
  *
  * libpng versions 1.2.6, August 15, 2004, through %VER%, %DATE%, are
  * Copyright (c) 2004, 2006-2013 Glenn Randers-Pehrson, and are
  * distributed according to the same disclaimer and license as libpng-1.2.5
  * with the following individual added to the list of Contributing Authors:
@@ -320,13 +320,13 @@
  * Y2K compliance in libpng:
  * =========================
  *
- *    %DATE%
+ *    January 30, 2015
  *
  *    Since the PNG Development group is an ad-hoc body, we can't make
  *    an official declaration.
  *
  *    This is your unofficial assurance that libpng from version 0.71 and
  *    upward through %VER% are Y2K compliant.  It is my belief that earlier
  *    versions were also Y2K compliant.
  *
  *    Libpng only has three year fields.  One is a 2-byte unsigned integer
@@ -382,22 +382,22 @@
  */
 
 /* Version information for png.h - this should match the version in png.c */
-#define PNG_LIBPNG_VER_STRING "%VER%"
+#define PNG_LIBPNG_VER_STRING "1.4.15beta02"
 #define PNG_HEADER_VERSION_STRING \
-   " libpng version %VER% - %DATE%\n"
+   " libpng version 1.4.15beta02 - January 30, 2015\n"
 
-#define PNG_LIBPNG_VER_SONUM   %SONUM%
-#define PNG_LIBPNG_VER_DLLNUM  %DLLNUM%
+#define PNG_LIBPNG_VER_SONUM   14
+#define PNG_LIBPNG_VER_DLLNUM  14
 
 /* These should match the first 3 components of PNG_LIBPNG_VER_STRING: */
-#define PNG_LIBPNG_VER_MAJOR   %MAJOR%
-#define PNG_LIBPNG_VER_MINOR   %MINOR%
-#define PNG_LIBPNG_VER_RELEASE %RELEASE%
+#define PNG_LIBPNG_VER_MAJOR   1
+#define PNG_LIBPNG_VER_MINOR   4
+#define PNG_LIBPNG_VER_RELEASE 15
 /* This should match the numeric part of the final component of
  * PNG_LIBPNG_VER_STRING, omitting any leading zero:
  */
 
-#define PNG_LIBPNG_VER_BUILD  %BUILDNUM%
+#define PNG_LIBPNG_VER_BUILD  02
 
 /* Release Status */
 #define PNG_LIBPNG_BUILD_ALPHA    1
@@ -414,7 +414,7 @@
 #define PNG_LIBPNG_BUILD_SPECIAL 32 /* Cannot be OR'ed with
                                        PNG_LIBPNG_BUILD_PRIVATE */
 
-#define PNG_LIBPNG_BUILD_BASE_TYPE %BUILDTYPE%
+#define PNG_LIBPNG_BUILD_BASE_TYPE PNG_LIBPNG_BUILD_BETA
 
 /* Careful here.  At one time, Guy wanted to use 082, but that would be octal.
  * We must not include leading zeros.
@@ -422,7 +422,7 @@
  * version 1.0.0 was mis-numbered 100 instead of 10000).  From
  * version 1.0.1 it's    xxyyzz, where x=major, y=minor, z=release
  */
-#define PNG_LIBPNG_VER %VER_NUM% /* %MAJOR%.%MINOR%.%RELEASE% */
+#define PNG_LIBPNG_VER 10415 /* 1.4.15 */
 
 #ifndef PNG_VERSION_INFO_ONLY
 /* Include the compression library's header */
@@ -765,9 +765,8 @@
     * single color specified that should be treated as fully transparent.
     * Data is valid if (valid & PNG_INFO_tRNS) is non-zero.
     */
-%12-%   png_bytep trans PNG_DEPSTRUCT;    /* alpha values for paletted image */
-%14+%   png_bytep trans_alpha PNG_DEPSTRUCT;    /* alpha values for paletted
-%14+%                                              image */
+   png_bytep trans_alpha PNG_DEPSTRUCT;    /* alpha values for paletted
+                                              image */
    png_color_16 trans_color PNG_DEPSTRUCT; /* transparent color for
                                               non-palette image */
 #endif
@@ -859,10 +858,8 @@
 #endif
 
 /* New members added in libpng-1.0.6 */
-%12-%#ifdef PNG_FREE_ME_SUPPORTED
    png_uint_32 free_me PNG_DEPSTRUCT;     /* flags items libpng is
                                              responsible for freeing */
-%12-%#endif
 
 #if defined(PNG_UNKNOWN_CHUNKS_SUPPORTED) || \
  defined(PNG_HANDLE_AS_UNKNOWN_SUPPORTED)
@@ -1072,7 +1069,6 @@
 #endif
 
 #if defined(PNG_READ_USER_TRANSFORM_SUPPORTED) || \
-%12-%    defined(PNG_LEGACY_SUPPORTED) || \
     defined(PNG_WRITE_USER_TRANSFORM_SUPPORTED)
 typedef void (PNGAPI *png_user_transform_ptr) PNGARG((png_structp,
     png_row_infop, png_bytep));
@@ -1206,8 +1202,7 @@
     * We will change the typedef from png_size_t to png_alloc_size_t
     * in libpng-1.6.0
     */
-%12-%   png_uint_32 user_chunk_cache_max PNG_DEPSTRUCT;
-%14+%   png_alloc_size_t user_chunk_malloc_max PNG_DEPSTRUCT;
+   png_alloc_size_t user_chunk_malloc_max PNG_DEPSTRUCT;
 #endif
    png_uint_32 iwidth PNG_DEPSTRUCT;        /* width of current interlaced
                                                row in pixels */
@@ -1253,13 +1248,8 @@
                                                start of file */
 
 #if defined(PNG_READ_FILLER_SUPPORTED) || defined(PNG_WRITE_FILLER_SUPPORTED)
-%12-%#ifdef PNG_LEGACY_SUPPORTED
-%12-%   png_byte filler PNG_DEPSTRUCT;           /* filler byte for pixel
-%12-%                                             expansion */
-%12-%#else
    png_uint_16 filler PNG_DEPSTRUCT;           /* filler bytes for pixel
                                                   expansion */
-%12-%#endif
 #endif
 
 #ifdef PNG_bKGD_SUPPORTED
@@ -1318,9 +1308,7 @@
 
 #if defined(PNG_tRNS_SUPPORTED) || defined(PNG_READ_BACKGROUND_SUPPORTED) \
  || defined(PNG_READ_EXPAND_SUPPORTED) || defined(PNG_READ_BACKGROUND_SUPPORTED)
-%12-%   png_bytep trans PNG_DEPSTRUCT;           /* alpha values for paletted
-%12-%                                               files */
-%14+%   png_bytep trans_alpha PNG_DEPSTRUCT;           /* alpha values for
+   png_bytep trans_alpha PNG_DEPSTRUCT;           /* alpha values for
                                                      paletted files */
    png_color_16 trans_color PNG_DEPSTRUCT;  /* transparent color for
                                                non-paletted files */
@@ -1417,10 +1405,8 @@
 
 /* New members added in libpng-1.0.6 */
 
-%12-%#ifdef PNG_FREE_ME_SUPPORTED
    png_uint_32 free_me PNG_DEPSTRUCT;    /* flags items libpng is
                                             responsible for freeing */
-%12-%#endif
 
 #ifdef PNG_USER_CHUNKS_SUPPORTED
    png_voidp user_chunk_ptr PNG_DEPSTRUCT;
@@ -1460,11 +1446,6 @@
    png_byte filter_type PNG_DEPSTRUCT;
 #endif
 
-%12-%/* New member added in libpng-1.0.10, ifdef'ed out in 1.2.0 */
-%12-%#if (defined(PNG_DEBUG) && defined(PNG_USE_PNGGCCRD))
-%12-%   png_uint_32 row_buf_size PNG_DEPSTRUCT;
-%12-%#endif
-%12-%
 /* New members added in libpng-1.2.0 */
 
 /* New members added in libpng-1.0.2 but first enabled by default in 1.2.0 */
@@ -1498,10 +1479,10 @@
 #ifdef PNG_USER_LIMITS_SUPPORTED
    png_uint_32 user_width_max PNG_DEPSTRUCT;
    png_uint_32 user_height_max PNG_DEPSTRUCT;
-%14+%   /* Added in libpng-1.4.0: Total number of sPLT, text, and unknown
-%14+%    * chunks that can be stored (0 means unlimited).
-%14+%    */
-%14+%   png_uint_32 user_chunk_cache_max PNG_DEPSTRUCT;
+   /* Added in libpng-1.4.0: Total number of sPLT, text, and unknown
+    * chunks that can be stored (0 means unlimited).
+    */
+   png_uint_32 user_chunk_cache_max PNG_DEPSTRUCT;
 #endif
 
 /* New member added in libpng-1.0.25 and 1.2.17 */
@@ -1527,7 +1508,7 @@
 /* This triggers a compiler error in png.c, if png.c and png.h
  * do not agree upon the version number.
  */
-typedef png_structp version_%_VER_%;
+typedef png_structp version_1_4_15beta02;
 
 typedef png_struct FAR * FAR * png_structpp;
 
@@ -1554,11 +1535,11 @@
 PNG_EXPORT(int,png_sig_cmp) PNGARG((png_bytep sig, png_size_t start,
    png_size_t num_to_check));
 
-%14+%/* Simple signature checking function.  This is the same as calling
-%14+% * png_check_sig(sig, n) := !png_sig_cmp(sig, 0, n).
-%14+% */
-%14+%#define png_check_sig(sig,n) !png_sig_cmp((sig), 0, (n))
-%14+%
+/* Simple signature checking function.  This is the same as calling
+ * png_check_sig(sig, n) := !png_sig_cmp(sig, 0, n).
+ */
+#define png_check_sig(sig,n) !png_sig_cmp((sig), 0, (n))
+
 /* Allocate and initialize png_ptr struct for reading, and any other memory. */
 PNG_EXPORT(png_structp,png_create_read_struct)
    PNGARG((png_const_charp user_png_ver, png_voidp error_ptr,
@@ -2050,22 +2031,17 @@
 PNG_EXPORT(png_voidp,png_get_mem_ptr) PNGARG((png_const_structp png_ptr));
 #endif
 
-%12-%#if defined(PNG_READ_USER_TRANSFORM_SUPPORTED) || \
-%12-%    defined(PNG_LEGACY_SUPPORTED)
-%14+%#ifdef PNG_READ_USER_TRANSFORM_SUPPORTED
+#ifdef PNG_READ_USER_TRANSFORM_SUPPORTED
 PNG_EXPORT(void,png_set_read_user_transform_fn) PNGARG((png_structp
    png_ptr, png_user_transform_ptr read_user_transform_fn));
 #endif
 
-%12-%#if defined(PNG_WRITE_USER_TRANSFORM_SUPPORTED) || \
-%12-%    defined(PNG_LEGACY_SUPPORTED)
-%14+%#ifdef PNG_WRITE_USER_TRANSFORM_SUPPORTED
+#ifdef PNG_WRITE_USER_TRANSFORM_SUPPORTED
 PNG_EXPORT(void,png_set_write_user_transform_fn) PNGARG((png_structp
    png_ptr, png_user_transform_ptr write_user_transform_fn));
 #endif
 
 #if defined(PNG_READ_USER_TRANSFORM_SUPPORTED) || \
-%12-%    defined(PNG_LEGACY_SUPPORTED) || \
     defined(PNG_WRITE_USER_TRANSFORM_SUPPORTED)
 PNG_EXPORT(void,png_set_user_transform_info) PNGARG((png_structp
    png_ptr, png_voidp user_transform_ptr, int user_transform_depth,
@@ -2108,9 +2084,9 @@
 
 PNG_EXPORT(png_voidp,png_malloc) PNGARG((png_structp png_ptr,
    png_alloc_size_t size)) PNG_ALLOCATED;
-%14+%/* Added at libpng version 1.4.0 */
-%14+%PNG_EXPORT(png_voidp,png_calloc) PNGARG((png_structp png_ptr,
-%14+%   png_alloc_size_t size)) PNG_ALLOCATED;
+/* Added at libpng version 1.4.0 */
+PNG_EXPORT(png_voidp,png_calloc) PNGARG((png_structp png_ptr,
+   png_alloc_size_t size)) PNG_ALLOCATED;
 
 /* Added at libpng version 1.2.4 */
 PNG_EXPORT(png_voidp,png_malloc_warn) PNGARG((png_structp png_ptr,
@@ -2122,12 +2098,10 @@
 /* Free data that was allocated internally */
 PNG_EXPORT(void,png_free_data) PNGARG((png_structp png_ptr,
    png_infop info_ptr, png_uint_32 free_me, int num));
-%12-%#ifdef PNG_FREE_ME_SUPPORTED
 /* Reassign responsibility for freeing existing data, whether allocated
  * by libpng or by the application */
 PNG_EXPORT(void,png_data_freer) PNGARG((png_structp png_ptr,
    png_infop info_ptr, int freer, png_uint_32 mask));
-%12-%#endif
 /* Assignments for png_data_freer */
 #define PNG_DESTROY_WILL_FREE_DATA 1
 #define PNG_SET_WILL_FREE_DATA 1
@@ -2481,15 +2455,13 @@
 
 #ifdef PNG_tRNS_SUPPORTED
 PNG_EXPORT(png_uint_32,png_get_tRNS) PNGARG((png_const_structp png_ptr,
-%12-%   png_infop info_ptr, png_bytep *trans, int *num_trans,
-%14+%   png_infop info_ptr, png_bytep *trans_alpha, int *num_trans,
+   png_infop info_ptr, png_bytep *trans_alpha, int *num_trans,
    png_color_16p *trans_color));
 #endif
 
 #ifdef PNG_tRNS_SUPPORTED
 PNG_EXPORT(void,png_set_tRNS) PNGARG((png_structp png_ptr,
-%12-%   png_infop info_ptr, png_bytep trans, int num_trans,
-%14+%   png_infop info_ptr, png_bytep trans_alpha, int num_trans,
+   png_infop info_ptr, png_bytep trans_alpha, int num_trans,
    png_color_16p trans_color));
 #endif
 
@@ -11,7 +11,7 @@
  *  libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
  *  libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- *  libpng versions 0.97, January 1998, through %VER% - %DATE%: Glenn
+ *  libpng versions 0.97, January 1998, through 1.4.15beta02 - January 30, 2015: Glenn
  *  See also "Contributing Authors", below.
  *
@@ -208,7 +208,7 @@
  * This code is released under the libpng license.
  *
- * libpng versions 1.2.6, August 15, 2004, through %VER%, %DATE%, are
+ * libpng versions 1.2.6, August 15, 2004, through 1.4.15beta02, January 30, 2015, are
  * Copyright (c) 2004, 2006-2013 Glenn Randers-Pehrson, and are
  * distributed according to the same disclaimer and license as libpng-1.2.5
@@ -320,13 +320,13 @@
  *
  *    This is your unofficial assurance that libpng from version 0.71 and
- *    upward through %VER% are Y2K compliant.  It is my belief that earlier
+ *    upward through 1.4.15beta02 are Y2K compliant.  It is my belief that earlier
  *    versions were also Y2K compliant.
  *